/*
 * display_task.c
 *
 *  Created on: 04-Jan-2021
 *      Author: MBRakshith
 */

#include "display_task.h"

#include "cyhal.h"
#include "cybsp.h"
#include "cy_retarget_io.h"

#include "GUI.h"
#include "mtb_st7789v.h"

#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"

//#include "images.h"

/* Display connections */
/** Pin for the Display Data8 signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DB8      (CYBSP_J2_2)
/** Pin for the Display Data9 signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DB9      (CYBSP_J2_4)
/** Pin for the Display Data10 signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DB10     (CYBSP_J2_6)
/** Pin for the Display Data11 signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DB11     (CYBSP_J2_10)
/** Pin for the Display Data12 signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DB12     (CYBSP_J2_12)
/** Pin for the Display Data13 signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DB13     (CYBSP_D7)
/** Pin for the Display Data14 signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DB14     (CYBSP_D8)
/** Pin for the Display Data15 signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DB15     (CYBSP_D9)
/** Pin for the Display Read signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_NRD      (CYBSP_D10)
/** Pin for the Display Write signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_NWR      (CYBSP_D11)
/** Pin for the Display D/C signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_DC       (CYBSP_D12)
/** Pin for the Display Reset signal */
#define CY8CKIT_028_TFT_PIN_DISPLAY_RST      (CYBSP_D13)


/*******************************************************************************
 * Global variables
 *******************************************************************************/
/* HAL SPI object to interface with display driver */
cyhal_spi_t spi;

/* The pins above are defined by the CY8CKIT-028-TFT library. If the display is being used on different hardware the mappings will be different. */
const mtb_st7789v_pins_t tft_pins =
{
    .db08 = CY8CKIT_028_TFT_PIN_DISPLAY_DB8,
    .db09 = CY8CKIT_028_TFT_PIN_DISPLAY_DB9,
    .db10 = CY8CKIT_028_TFT_PIN_DISPLAY_DB10,
    .db11 = CY8CKIT_028_TFT_PIN_DISPLAY_DB11,
    .db12 = CY8CKIT_028_TFT_PIN_DISPLAY_DB12,
    .db13 = CY8CKIT_028_TFT_PIN_DISPLAY_DB13,
    .db14 = CY8CKIT_028_TFT_PIN_DISPLAY_DB14,
    .db15 = CY8CKIT_028_TFT_PIN_DISPLAY_DB15,
    .nrd  = CY8CKIT_028_TFT_PIN_DISPLAY_NRD,
    .nwr  = CY8CKIT_028_TFT_PIN_DISPLAY_NWR,
    .dc   = CY8CKIT_028_TFT_PIN_DISPLAY_DC,
    .rst  = CY8CKIT_028_TFT_PIN_DISPLAY_RST
};

void display_task(void *arg)
{
	cy_rslt_t result;

	cyhal_gpio_init( CYBSP_USER_LED, CYHAL_GPIO_DIR_OUTPUT, CYHAL_GPIO_DRIVE_STRONG,
				CYBSP_LED_STATE_OFF);

	/* Initialize the display controller */
	result = mtb_st7789v_init8(&tft_pins);
	CY_ASSERT(result == CY_RSLT_SUCCESS);

	/* GUI Init is done in MainTask in MOVIE_ShowFeatures.c */
//	GUI_Init();

	printf("Display initialization Complete\n\n\r");

//	GUI_DispString("Hello world!");

	/* Running the MainTask() function defined in MOVIE_ShowFeatures.c */

	MainTask();

	for(;;)
	{
		printf("Toggling LED\n\r");
		cyhal_gpio_toggle(CYBSP_USER_LED);
		vTaskDelay(500);
	}

}




